==> telephone_type-8.x-3.2.tar.gz: telephone_type/tests/src/Kernel/TelephoneTypeItemTest.php <==
<?php

namespace Drupal\Tests\telephone_type\Kernel;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\FieldItemInterface;
use Drupal\entity_test\Entity\EntityTest;
use Drupal\field\Entity\FieldConfig;
use Drupal\Tests\field\Kernel\FieldKernelTestBase;
use Drupal\field\Entity\FieldStorageConfig;

/**
 * Tests the new entity API for the telephone_type field type.
 *
 * @group telephone_type
 */
class TelephoneTypeItemTest extends FieldKernelTestBase {

  /**
   * Modules to enable.
   *
   * @var array
   */
  public static $modules = ['telephone_type'];

  /**
   * Protected Function setup.
   */
  protected function setUp() {
    parent::setUp();

    // Create a telephone field storage and field for validation.
    FieldStorageConfig::create([
      'field_name' => 'field_test',
      'entity_type' => 'entity_test',
      'type' => 'telephone_type',
    ])->save();
    FieldConfig::create([
      'entity_type' => 'entity_test',
      'field_name' => 'field_test',
      'bundle' => 'entity_test',
    ])->save();
  }

  /**
   * Tests using entity fields of the telephone_type field type.
   */
  public function testTestItem() {
    // Verify entity creation.
    $entity = EntityTest::create();
    $value = '+0123456789';
    $type = 'Work';
    $entity->field_test->value = $value;
    $entity->field_test->type = $type;
    $entity->name->value = $this->randomMachineName();
    $entity->save();

    // Verify entity has been created properly.
    $id = $entity->id();
    $entity = EntityTest::load($id);
    $this->assertTrue($entity->field_test instanceof FieldItemListInterface, 'Field implements interface.');
    $this->assertTrue($entity->field_test[0] instanceof FieldItemInterface, 'Field item implements interface.');
    $this->assertEqual($entity->field_test->value, $value);
    $this->assertEqual($entity->field_test->type, $type);
    $this->assertEqual($entity->field_test[0]->value, $value);
    $this->assertEqual($entity->field_test[0]->type, $type);

    // Verify changing the field value.
    $new_value = '+41' . rand(1000000, 9999999);
    $new_type = 'Cell';
    $entity->field_test->value = $new_value;
    $entity->field_test->type = $new_type;
    $this->assertEqual($entity->field_test->value, $new_value);
    $this->assertEqual($entity->field_test->type, $new_type);

    // Read changed entity and assert changed values.
    $entity->save();
    $entity = EntityTest::load($id);
    $this->assertEqual($entity->field_test->value, $new_value);
    $this->assertEqual($entity->field_test->type, $new_type);

    // Test sample item generation.
    $entity = EntityTest::create();
    $entity->field_test->generateSampleItems();
    $this->entityValidateAndSave($entity);
  }

}

==> telephone_type-8.x-3.3.tar.gz: telephone_type/tests/src/Kernel/TelephoneTypeItemTest.php <==
<?php

namespace Drupal\Tests\telephone_type\Kernel;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\FieldItemInterface;
use Drupal\entity_test\Entity\EntityTest;
use Drupal\field\Entity\FieldConfig;
use Drupal\Tests\field\Kernel\FieldKernelTestBase;
use Drupal\field\Entity\FieldStorageConfig;

/**
 * Tests the new entity API for the telephone_type field type.
 *
 * @group telephone_type
 */
class TelephoneTypeItemTest extends FieldKernelTestBase {

  /**
   * Modules to enable.
   *
   * @var array
   */
  protected static $modules = ['telephone_type'];

  /**
   * Protected Function setup.
   */
  protected function setUp(): void {
    parent::setUp();

    // Create a telephone field storage and field for validation.
    FieldStorageConfig::create([
      'field_name' => 'field_test',
      'entity_type' => 'entity_test',
      'type' => 'telephone_type',
    ])->save();
    FieldConfig::create([
      'entity_type' => 'entity_test',
      'field_name' => 'field_test',
      'bundle' => 'entity_test',
    ])->save();
  }

  /**
   * Tests using entity fields of the telephone_type field type.
   */
  public function testTestItem() {
    // Verify entity creation.
    $entity = EntityTest::create();
    $value = '+0123456789';
    $type = 'Work';
    $entity->field_test->value = $value;
    $entity->field_test->type = $type;
    $entity->name->value = $this->randomMachineName();
    $entity->save();

    // Verify entity has been created properly.
    $id = $entity->id();
    $entity = EntityTest::load($id);
    $this->assertTrue($entity->field_test instanceof FieldItemListInterface, 'Field implements interface.');
    $this->assertTrue($entity->field_test[0] instanceof FieldItemInterface, 'Field item implements interface.');
    $this->assertEquals($entity->field_test->value, $value);
    $this->assertEquals($entity->field_test->type, $type);
    $this->assertEquals($entity->field_test[0]->value, $value);
    $this->assertEquals($entity->field_test[0]->type, $type);

    // Verify changing the field value.
    $new_value = '+41' . rand(1000000, 9999999);
    $new_type = 'Cell';
    $entity->field_test->value = $new_value;
    $entity->field_test->type = $new_type;
    $this->assertEquals($entity->field_test->value, $new_value);
    $this->assertEquals($entity->field_test->type, $new_type);

    // Read changed entity and assert changed values.
    $entity->save();
    $entity = EntityTest::load($id);
    $this->assertEquals($entity->field_test->value, $new_value);
    $this->assertEquals($entity->field_test->type, $new_type);

    // Test sample item generation.
    $entity = EntityTest::create();
    $entity->field_test->generateSampleItems();
    $this->entityValidateAndSave($entity);
  }

}
